@@ -85,7 +85,6 @@ namespace Intrepid2 {
         << "| TEST 1: integrals of monomials in 3D                                        |\n"
         << "===============================================================================\n";
       
-      typedef Kokkos::DynRankView<ValueType,DeviceType> DynRankView;
 #define ConstructWithLabel(obj, ...) obj(#obj, __VA_ARGS__)
 
       typedef ValueType pointValueType;
@@ -108,43 +107,47 @@ namespace Intrepid2 {
         // analytic integral values
         const auto analyticMaxDeg = 20;
 
-        // storage for cubatrue points and weights
-        DynRankView ConstructWithLabel(cubPoints,
-                                       Parameters::MaxIntegrationPoints,
-                                       Parameters::MaxDimension);
-
-        DynRankView ConstructWithLabel(cubWeights,
-                                       Parameters::MaxIntegrationPoints);
-
         // perform comparison
         for (auto cubDeg=0;cubDeg<=maxDeg;++cubDeg) {
 
           *outStream << "Testing Default Cubature of Order " << std::setw(2) << std::left << cubDeg << "\n";
 
           CubatureTetType tetCub(cubDeg);
+          auto cubPoints  = tetCub.allocateCubaturePoints();
+          auto cubWeights = tetCub.allocateCubatureWeights();
+          tetCub.getCubature(cubPoints, cubWeights);
 
           const auto y_offs = (analyticMaxDeg - cubDeg);
           const auto x_offs = y_offs*(y_offs + 1)/2;
           ordinal_type offset = 0;
           const auto oldFlag = errorFlag;
-          for (auto xDeg=0;xDeg<=cubDeg;++xDeg,offset += x_offs) 
-            for (auto yDeg=0;yDeg<=(cubDeg-xDeg);++yDeg,offset += y_offs) 
-              for (auto zDeg=0;zDeg<=(cubDeg-xDeg-yDeg);++zDeg) {
+          Kokkos::Array<int,3> degrees;
+          for (auto xDeg=0;xDeg<=cubDeg;++xDeg,offset += x_offs)
+          {
+            degrees[0] = xDeg;
+            for (auto yDeg=0;yDeg<=(cubDeg-xDeg);++yDeg,offset += y_offs)
+            {
+              degrees[1] = yDeg;
+              for (auto zDeg=0;zDeg<=(cubDeg-xDeg-yDeg);++zDeg)
+              {
+                degrees[2] = zDeg;
                 const auto analyticIntegral = analyticIntegralOfMonomialOverTet<ValueType>(xDeg,yDeg,zDeg);
                 const auto abstol  = std::fabs(tol*analyticIntegral );
-                const auto computedIntegral = computeIntegralOfMonomial<ValueType>(tetCub,cubPoints,cubWeights,xDeg,yDeg,zDeg);
+                const auto computedIntegral = computeIntegralOfMonomial<ValueType>(cubPoints,cubWeights,degrees);
                 const auto absdiff = std::fabs(analyticIntegral - computedIntegral);
                 if (absdiff > abstol) {
                   *outStream << "Default Cubature of Order " << std::setw(2) << std::left << cubDeg << " Integrating "
-                             << "x^" << std::setw(2) << std::left << xDeg << " * y^" << std::setw(2) << yDeg
-                             << " * z^" << std::setw(2) << zDeg << ":" << "   "
-                             << std::scientific << std::setprecision(16)
-                             << computedIntegral << "   " << analyticIntegral << "   "
-                             << std::setprecision(4) << absdiff << "   " << "<?" << "   " << abstol << "\n";
+                  << "x^" << std::setw(2) << std::left << xDeg << " * y^" << std::setw(2) << yDeg
+                  << " * z^" << std::setw(2) << zDeg << ":" << "   "
+                  << std::scientific << std::setprecision(16)
+                  << computedIntegral << "   " << analyticIntegral << "   "
+                  << std::setprecision(4) << absdiff << "   " << "<?" << "   " << abstol << "\n";
                   errorFlag++;
                   *outStream << std::right << std::setw(118) << "^^^^---FAILURE!\n";
                 }
               }
+            }
+          }
           *outStream << "Default Cubature of Order " << std::setw(2) << std::left << cubDeg
                      << (errorFlag == oldFlag ? "  PASSED" : "  FAILED") << std::endl;                         
         }
@@ -155,13 +158,17 @@ namespace Intrepid2 {
           *outStream << "Testing Symmetric Cubature of Order " << std::setw(2) << std::left << cubDeg << "\n";
 
           CubatureTetSymType tetCub(cubDeg);
+          auto cubPoints  = tetCub.allocateCubaturePoints();
+          auto cubWeights = tetCub.allocateCubatureWeights();
           tetCub.getCubature(cubPoints, cubWeights);
-          auto cubWeights_host = Kokkos::create_mirror_view_and_copy(Kokkos::HostSpace(), cubWeights);
-          ValueType minWeigth = 1.0;
+          
+          using HostDevice = Kokkos::HostSpace::device_type;
+          TensorData<weightValueType,HostDevice> cubWeightsHost(cubWeights); // this constructor does any necessary allocation and copying to host
+          ValueType minWeight = 1.0;
           for(int i=0; i<tetCub.getNumPoints();++i)
-            minWeigth = std::min(minWeigth,cubWeights_host(i));
+            minWeight = std::min(minWeight,cubWeightsHost(i));
 
-          if (minWeigth <= 0.0) {
+          if (minWeight <= 0.0) {
             errorFlag++;
             *outStream << "   Cubature Rule is not positive!\n" << std::right << std::setw(111) << "^^^^---FAILURE!\n";
           }
@@ -170,26 +177,35 @@ namespace Intrepid2 {
           const auto x_offs = y_offs*(y_offs + 1)/2;
           ordinal_type offset = 0;
           const auto oldFlag = errorFlag;
-          for (auto xDeg=0;xDeg<=cubDeg;++xDeg,offset += x_offs) 
-            for (auto yDeg=0;yDeg<=(cubDeg-xDeg);++yDeg,offset += y_offs) 
-              for (auto zDeg=0;zDeg<=(cubDeg-xDeg-yDeg);++zDeg) {
+          Kokkos::Array<int,3> degrees;
+          for (auto xDeg=0;xDeg<=cubDeg;++xDeg,offset += x_offs)
+          {
+            degrees[0] = xDeg;
+            for (auto yDeg=0;yDeg<=(cubDeg-xDeg);++yDeg,offset += y_offs)
+            {
+              degrees[1] = yDeg;
+              for (auto zDeg=0;zDeg<=(cubDeg-xDeg-yDeg);++zDeg)
+              {
+                degrees[2] = zDeg;
                 const auto analyticIntegral = analyticIntegralOfMonomialOverTet<ValueType>(xDeg,yDeg,zDeg);
-                const auto computedIntegral = computeIntegralOfMonomial<ValueType>(tetCub,cubPoints,cubWeights,xDeg,yDeg,zDeg);
+                const auto computedIntegral = computeIntegralOfMonomial<ValueType>(cubPoints,cubWeights,degrees);
                 const auto abstol  = std::fabs(tol*analyticIntegral );
                 const auto absdiff = std::fabs(analyticIntegral - computedIntegral);
                 if (absdiff > abstol) {
                   *outStream << "Symmetric Cubature order " << std::setw(2) << std::left << cubDeg << " integrating "
-                             << "x^" << std::setw(2) << std::left << xDeg << " * y^" << std::setw(2) << yDeg
-                             << " * z^" << std::setw(2) << zDeg << ":" << "   "
-                             << std::scientific << std::setprecision(16)
-                             << computedIntegral << "   " << analyticIntegral << "   "
-                             << std::setprecision(4) << absdiff << "   " << "<?" << "   " << abstol << "\n";
+                  << "x^" << std::setw(2) << std::left << xDeg << " * y^" << std::setw(2) << yDeg
+                  << " * z^" << std::setw(2) << zDeg << ":" << "   "
+                  << std::scientific << std::setprecision(16)
+                  << computedIntegral << "   " << analyticIntegral << "   "
+                  << std::setprecision(4) << absdiff << "   " << "<?" << "   " << abstol << "\n";
                   errorFlag++;
                   *outStream << std::right << std::setw(118) << "^^^^---FAILURE!\n";
                 }
               }
+            }
+          }
           *outStream << "Symmetric Cubature of Order " << std::setw(2) << std::left << cubDeg
-                     << (errorFlag == oldFlag ? "  PASSED" : "  FAILED") << std::endl;                         
+                     << (errorFlag == oldFlag ? "  PASSED" : "  FAILED") << std::endl;
         }
         *outStream << "\n";
       } catch (std::logic_error &err) {
